@@ -16,6 +16,7 @@ from requests.adapters import HTTPAdapter, Retry
 from pystac import Collection, Item, ItemCollection
 from rich.pretty import pretty_repr
 
+from teledetection.sdk.settings import ENV
 from teledetection.sdk.logger import get_logger_for
 from teledetection.sdk.http import get_headers
 from teledetection.sdk.signing import sign, sign_inplace
@@ -23,6 +24,7 @@ from .transfer import push
 from . import raster
 
 logger = get_logger_for(__name__)
+TIMEOUT = ENV.tld_request_timeout
 
 DEFAULT_STAC_EP = "https://api.stac.teledetection.fr"
 DEFAULT_S3_EP = "https://s3-data.meso.umontpellier.fr"
@@ -97,7 +99,7 @@ def post_or_put(url: str, data: dict):
     headers = get_headers()
     sess = create_session()
 
-    resp = sess.post(url, json=data, headers=headers, timeout=10)
+    resp = sess.post(url, json=data, headers=headers, timeout=TIMEOUT)
 
     if resp.status_code == 409:
         # Exists, so update
@@ -106,7 +108,7 @@ def post_or_put(url: str, data: dict):
             f"{url}/{data['id']}",
             json=data,
             headers=headers,
-            timeout=10,
+            timeout=TIMEOUT,
         )
         # Unchanged may throw a 404
         if not resp.status_code == 404:
@@ -189,8 +191,9 @@ def get_col_items(col: Collection) -> List[Item]:
 class StacTransactionsHandler:
     """Handle STAC and storage transactions."""
 
-    stac_endpoint: str
-    sign: bool
+    stac_endpoint: str = DEFAULT_STAC_EP
+    sign: bool = False
+    """Sign URLs when fetching remote items."""
 
     @property
     def client(self):
@@ -210,7 +213,7 @@ class StacTransactionsHandler:
         resp = requests.delete(
             url,
             headers=get_headers(),
-            timeout=5,
+            timeout=TIMEOUT,
         )
         if resp.status_code != 200:
             logger.warning("Deletion failed (%s)", resp.text)
@@ -290,9 +293,10 @@ class StacTransactionsHandler:
 class StacUploadTransactionsHandler(StacTransactionsHandler):
     """Handle STAC and storage transactions."""
 
-    storage_endpoint: str
-    storage_bucket: str
-    assets_overwrite: bool
+    storage_endpoint: str = DEFAULT_S3_EP
+    storage_bucket: str = DEFAULT_S3_STORAGE
+    assets_overwrite: bool = False
+    """Overwrite assets on S3 if already existing."""
     keep_cog_dir: str = ""
 
     def publish_item_and_push_assets(self, item: Item, assets_root_dir: str):
